import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'organization.m.dart';


class OrganizationService extends JsonRpcClientBase {
	OrganizationService(
		String host, {
		String serviceName = "IOrganizationService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => OrganizationDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => OrganizationBaseDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => OrganizationBasicDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => OrganizationSettingResult.fromJson(map));
	}

	Future<List<OrganizationDTO>> searchOrganizations(SearchOrganizationsRequest request) async {
		var rpcRst = await call("SearchOrganizations", request);
		var result = (rpcRst as List).map((e)=>OrganizationDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<OrganizationDTO> getOrganizationByCode(GetOrganizationByCodeRequest request) async {
		var rpcRst = await call("GetOrganizationByCode", request);
		var result = OrganizationDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<OrganizationBaseDTO>> getParentOrganizationListAsync(GetParentOrganizationListRequest request) async {
		var rpcRst = await call("GetParentOrganizationListAsync", request);
		var result = (rpcRst as List).map((e)=>OrganizationBaseDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<OrganizationBasicDTO> getPersonOrganizationAsync(GetPersonOrganizationRequest request) async {
		var rpcRst = await call("GetPersonOrganizationAsync", request);
		var result = OrganizationBasicDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> savePersonOrganizationAsync(SavePersonOrganizationRequest request) async {
		var rpcRst = await call("SavePersonOrganizationAsync", request);
		return rpcRst;
	}

	Future<bool> addOrganizations(AddOrganizationsRequest request) async {
		var rpcRst = await call("AddOrganizations", request);
		return rpcRst;
	}

	Future<bool> removeOrganizations(RemoveOrganizationsRequest request) async {
		var rpcRst = await call("RemoveOrganizations", request);
		return rpcRst;
	}

	Future<bool> updateOrganizationName(UpdateOrganizationNameRequest request) async {
		var rpcRst = await call("UpdateOrganizationName", request);
		return rpcRst;
	}

	Future<OrganizationSettingResult> getOrganizationSetting(GetUserOrganizationSettingRequest request) async {
		var rpcRst = await call("GetOrganizationSetting", request);
		var result = OrganizationSettingResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<OrganizationSettingResult> getServerLangugeSetting(GetServerLangugeSettingRequest request) async {
		var rpcRst = await call("GetServerLangugeSetting", request);
		var result = OrganizationSettingResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

