import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'patient.m.dart';


class PatientService extends JsonRpcClientBase {
	PatientService(
		String host, {
		String serviceName = "IPatientService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => PageResult<ClientPatientInfoBaseDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => ClientPatientInfoBaseDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => ClientPatientInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PatientInfoDTO.fromJson(map));
	}

	Future<bool> createPatient(CreatePatientRequest request) async {
		var rpcRst = await call("CreatePatient", request);
		return rpcRst;
	}

	Future<bool> updatePatient(UpdatePatientRequest request) async {
		var rpcRst = await call("UpdatePatient", request);
		return rpcRst;
	}

	Future<bool> createPatients(CreatePatientsRequest request) async {
		var rpcRst = await call("CreatePatients", request);
		return rpcRst;
	}

	Future<PageResult<ClientPatientInfoBaseDTO>> findPatients(FindPatientsPageRequest request) async {
		var rpcRst = await call("FindPatients", request);
		var result = PageResult<ClientPatientInfoBaseDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<ClientPatientInfoDTO> findPatientByCode(FindPatientByCodeRequest request) async {
		var rpcRst = await call("FindPatientByCode", request);
		var result = ClientPatientInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PatientInfoDTO> assignPatientToUsers(AssignPatientToUsersRequest request) async {
		var rpcRst = await call("AssignPatientToUsers", request);
		var result = PatientInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<ClientPatientInfoBaseDTO>> findValidPatientsByName(FindValidPatientsByNameRequest request) async {
		var rpcRst = await call("FindValidPatientsByName", request);
		var result = (rpcRst as List).map((e)=>ClientPatientInfoBaseDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> setValidPatient(SetValidPatientRequest request) async {
		var rpcRst = await call("SetValidPatient", request);
		return rpcRst;
	}

	Future<bool> removePatientsAsync(RemovePatientsRequest request) async {
		var rpcRst = await call("RemovePatientsAsync", request);
		return rpcRst;
	}

}

