import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'position.m.dart';


class PositionService extends JsonRpcClientBase {
	PositionService(
		String host, {
		String serviceName = "IPositionService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => PositionDTO.fromJson(map));
	}

	Future<List<PositionDTO>> getPositions(GetPositionsRequest request) async {
		var rpcRst = await call("GetPositions", request);
		var result = (rpcRst as List).map((e)=>PositionDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> addPositions(AddPositionsRequest request) async {
		var rpcRst = await call("AddPositions", request);
		return rpcRst;
	}

	Future<bool> removePositions(RemovePositionRequest request) async {
		var rpcRst = await call("RemovePositions", request);
		return rpcRst;
	}

	Future<bool> updatePositionName(UpdatePositionNameRequest request) async {
		var rpcRst = await call("UpdatePositionName", request);
		return rpcRst;
	}

}

