import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'user.m.dart';

import 'authentication.m.dart';
import 'patient.m.dart';


class UserService extends JsonRpcClientBase {
	UserService(
		String host, {
		String serviceName = "IUserService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => UserDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<ShareDeviceUserDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => ShareDeviceUserDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => UserFeatureInfoResult.fromJson(map));
	}

	Future<UserDTO> getUserInfoAsync(GetUserInfoRequest request) async {
		var rpcRst = await call("GetUserInfoAsync", request);
		var result = UserDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> alterUserInfoAsync(AlterUserInfoRequest request) async {
		var rpcRst = await call("AlterUserInfoAsync", request);
		return rpcRst;
	}

	Future<List<UserDTO>> getUserList(GetUserListRequest request) async {
		var rpcRst = await call("GetUserList", request);
		var result = (rpcRst as List).map((e)=>UserDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> removeUsersFromOrganization(RemoveUsersFromOrganizationRequest request) async {
		var rpcRst = await call("RemoveUsersFromOrganization", request);
		return rpcRst;
	}

	Future<bool> setUserOrganizationInfo(SetUserOrganizationInfoRequest request) async {
		var rpcRst = await call("SetUserOrganizationInfo", request);
		return rpcRst;
	}

	Future<bool> alterPersonInfoAsync(AlterPersonInfoRequest request) async {
		var rpcRst = await call("AlterPersonInfoAsync", request);
		return rpcRst;
	}

	Future<PageResult<ShareDeviceUserDTO>> getShareDeviceUsers(GetShareDeviceUsersPageRequest request) async {
		var rpcRst = await call("GetShareDeviceUsers", request);
		var result = PageResult<ShareDeviceUserDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<UserFeatureInfoResult>> getUserFeatureListAsync(TokenRequest request) async {
		var rpcRst = await call("GetUserFeatureListAsync", request);
		var result = (rpcRst as List).map((e)=>UserFeatureInfoResult.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<UserDTO> getUserByCodeAsync(GetUserByCodeRequest request) async {
		var rpcRst = await call("GetUserByCodeAsync", request);
		var result = UserDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> isDefaultPasswordAsync(TokenRequest request) async {
		var rpcRst = await call("IsDefaultPasswordAsync", request);
		return rpcRst;
	}

}

